@@ -1,7 +1,7 @@
 #ifndef __GWEATHER_PREF_H_
 #define __GWEATHER_PREF_H_
 
-/* $Id: gweather-pref.h,v 1.6 2002/03/26 01:44:04 kevinv Exp $ */
+/* $Id: gweather-pref.h,v 1.9 2004/06/20 20:56:14 dsmit Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -26,6 +26,13 @@ extern void gweather_pref_save (const gchar *path, GWeatherApplet *gw_applet);
 void add_atk_relation (GtkWidget *widget1, GtkWidget *widget2, AtkRelationType type);
 void set_access_namedesc (GtkWidget *widget, const gchar *name, const gchar *desc);
 
+enum
+{
+    GWEATHER_PREF_COL_LOC = 0,
+    GWEATHER_PREF_COL_POINTER,
+    GWEATHER_PREF_NUM_COLUMNS
+}; 
+
 
 
 G_END_DECLS
