@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.88 2004/07/07 00:57:57 gowen Exp $ */
+/* $Id: weather.c,v 1.93.2.2 2004/10/13 12:11:44 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -57,6 +57,7 @@ static gboolean weather_radar = FALSE;
 #define WINDSPEED_KNOTS_TO_MPH(knots)  ((knots) * 1.150779)
 #define WINDSPEED_KNOTS_TO_MS(knots)   ((knots) * 0.514444)
 
+#define PRESSURE_INCH_TO_KPA(inch)   ((inch) * 3.386)
 #define PRESSURE_INCH_TO_HPA(inch)   ((inch) * 33.86)
 #define PRESSURE_INCH_TO_MM(inch)    ((inch) * 25.40005)
 #define PRESSURE_INCH_TO_MB(inch)    (PRESSURE_INCH_TO_HPA(inch))
@@ -1362,33 +1363,33 @@ static char *met_reprocess(char *x, int len)
 	{
 		if(buf)
 			g_free(buf);
-		buf=g_malloc(len);
+		buf=g_malloc(len + 1);
 		buflen=len;
 	}
-	memcpy(buf, x, len);
 		
 	o=buf;
+	x += len;       /* End mark */
 
-	while(*p)
+	while(*p && p < x)
 	{
 		if(isspace(*p))
 		{
-			spacing=1;
+			if(!spacing)
+			{
+				spacing = 1;
+				lastspace = o;
+				count++;
+				*o++ = ' ';
+			}
 			p++;
 			continue;
 		}
-		if(spacing)
+		spacing = 0;
+		if(count > 75 && lastspace)
 		{
-			if(count>75)
-			{
-				if(lastspace)
-					*lastspace = '\n';
-				count -= lastcount;
-			}
-			lastspace = o;
-			lastcount = count;
-			*o++=' ';
-			spacing=0;
+			count = o - lastspace - 1;
+			*lastspace = '\n';
+			lastspace = NULL;
 		}
 
 		if(*p=='&')
@@ -1420,12 +1421,20 @@ static char *met_reprocess(char *x, int len)
 			if(strncasecmp(p, "<BR>", 4)==0)
 			{
 				*o++='\n';
-				count=0;
-				lastspace = NULL;
-				p+=4;
-				continue;
+				count = 0;
 			}
-			break;
+			if(strncasecmp(p, "<B>", 3)==0)
+			{
+				*o++='\n';
+				*o++='\n';
+				count = 0;
+			}
+			p++;
+			while(*p && *p != '>')
+				p++;
+			if(*p)
+				p++;
+			continue;
 		}
 		*o++=*p++;
 		count++;
@@ -1437,7 +1446,7 @@ static char *met_reprocess(char *x, int len)
 
 /*
  * Parse the metoffice forecast info.
- * For gnome 2.0 we want to just embed an HTML bonobo component and 
+ * For gnome 3.0 we want to just embed an HTML bonobo component and 
  * be done with this ;) 
  */
 
@@ -1449,59 +1458,18 @@ static gchar *met_parse (gchar *meto, WeatherLocation *loc)
     gchar *t;    
     gint i=0;
 
-    static char *key[]=
-    {
-    	"<!-- <!TODAY_START> -->",
-    	"<!-- <!TONIGHT_START> -->",
-    	"<!-- <!TOMORROW_START> -->",
-    	"<!-- <!OUTLOOK_START> -->",
-    	NULL
-    };
-    static char *keyend[]=
-    {
-    	"<!-- <!TODAY_END> -->",
-    	"<!-- <!TONIGHT_END> -->",
-    	"<!-- <!TOMORROW_END> -->",
-    	"<!-- <!OUTLOOK_END> -->",
-    	NULL
-    };
-    static char *name[4]=
-    {
-    	"Today:",
-    	"Tonight:",
-    	"Tomorrow:",
-    	"Outlook:"
-    };
-    
-    
-    while(key[i]!=NULL)
-    {
-    	p=strstr(meto, key[i]);
-    	if(p==NULL)
-    	{
-    		printf("No %s\n", key[i]);
-    		i++;
-    		continue;
-    	}
-    	p+=strlen(key[i]);
+    p = strstr(meto, "Summary: </b>");
+    if(p == NULL)
+	    return r;
+    p += 13;
+    rp = strstr(p, "Text issued at:");
+    if(rp == NULL)
+	    return r;
 
-    	rp = strstr(p, keyend[i]);
-	if(rp==NULL)
-	{
-    		printf("No %s\n", keyend[i]);
-		i++;
-		continue;
-	}
-	
-	/* p to rp is the text block we want but in HTML malformat */    	
-
-    	t = g_strconcat(r, name[i], "\n", met_reprocess(p, rp-p), "\n", NULL);
-    	
-    	g_free(r);
-    	r = t;
-    	i++;
-    }
-    return r;
+    /* p to rp is the text block we want but in HTML malformat */
+    t = g_strconcat(r, met_reprocess(p, rp-p), NULL);
+    free(r);
+    return t;
 }
 
 static void met_finish_read(GnomeVFSAsyncHandle *handle, GnomeVFSResult result, 
@@ -1595,7 +1563,7 @@ static void metoffice_start_open (WeatherInfo *info)
     WeatherLocation *loc;
     loc = info->location;
   
-    url = g_strdup_printf("http://www.metoffice.gov.uk/datafiles/%s.html", loc->zone+1);
+    url = g_strdup_printf("http://www.metoffice.gov.uk/weather/europe/uk/%s.html", loc->zone+1);
 
     gnome_vfs_async_open(&info->met_handle, url, GNOME_VFS_OPEN_READ, 
     			 0, met_finish_open, info->applet);
@@ -1840,7 +1808,7 @@ static void wx_finish_open (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 	
     body = g_malloc0(DATA_SIZE);
 
-    info->radar_buffer = NULL;	
+    info->radar_buffer = NULL;
     info->radar = NULL;
     loc = info->location;
     g_return_if_fail(loc != NULL);
@@ -1906,7 +1874,6 @@ gboolean _weather_info_fill (GWeatherApplet *applet, WeatherInfo *info, WeatherL
     	info->location = weather_location_clone(location);
     } else {
         location = info->location;
-        /* g_free(info->forecast); */
 	    if (info->forecast)
 	    	g_free (info->forecast);
 	    info->forecast = NULL;
@@ -2264,11 +2231,12 @@ const gchar *weather_info_get_dew (WeatherInfo *info)
 const gchar *weather_info_get_humidity (WeatherInfo *info)
 {
     static gchar buf[20];
+    gdouble humidity;
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "-";
 
-    gdouble humidity = calc_humidity(info->temp, info->dew);
+    humidity = calc_humidity(info->temp, info->dew);
     if (humidity < 0.0)
         return _("Unknown");
 
@@ -2279,11 +2247,12 @@ const gchar *weather_info_get_humidity (WeatherInfo *info)
 
 const gchar *weather_info_get_apparent (WeatherInfo *info)
 {
+    gdouble apparent;
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "-";
 
-    gdouble apparent = calc_apparent(info);
+    apparent = calc_apparent(info);
     if (apparent < -500.0)
         return _("Unknown");
     
@@ -2308,7 +2277,7 @@ static const gchar *windspeed_string (gfloat knots, SpeedUnit to_unit)
             g_snprintf(buf, sizeof (buf), _("%.1f km/h"), WINDSPEED_KNOTS_TO_KPH(knots));
             break;
         case SPEED_UNIT_MS:
-            /* TRANSLATOR: This is the wind speed in miles per hour */
+            /* TRANSLATOR: This is the wind speed in meters per second */
             g_snprintf(buf, sizeof (buf), _("%.1f m/s"), WINDSPEED_KNOTS_TO_MS(knots));
             break;
 
@@ -2358,6 +2327,10 @@ const gchar *weather_info_get_pressure (WeatherInfo *info)
             /* TRANSLATOR: This is pressure in millimeters of mercury */
             g_snprintf (buf, sizeof (buf), _("%.1f mmHg"), PRESSURE_INCH_TO_MM(info->pressure));
             break;
+        case PRESSURE_UNIT_KPA:
+            /* TRANSLATOR: This is pressure in kiloPascals */
+            g_snprintf (buf, sizeof (buf), _("%.2f kPa"), PRESSURE_INCH_TO_KPA(info->pressure));
+            break;
         case PRESSURE_UNIT_HPA:
             /* TRANSLATOR: This is pressure in hectoPascals */
             g_snprintf (buf, sizeof (buf), _("%.2f hPa"), PRESSURE_INCH_TO_HPA(info->pressure));
